@@ -3,19 +3,22 @@ package Acme::CPANAuthors::Japanese;
 use strict;
 use warnings;
 
-our $VERSION = '0.131002';
+our $VERSION = '0.140828';
 
 use Acme::CPANAuthors::Register (
     ABUI      => 'DAISUKE ABUI',
     ACE       => 'yuichi tsunoda',
     ACIDLEMON => 'Masatoshi Kawazoe',
     ACOTIE    => 'Akiko Yokoyama',
+    ADDSICT   => 'Yuuki Furuyama',
+    ADOKOY    => 'Toshiaki Yokoda',
     AERDAN    => 'Kiyoshi Aman',
     AGREW     => 'Naoyuki Okumura',
     AHIGUCHI  => 'Akira Higuchi',
     AHIGUTI   => 'Akira Higuchi',
     AHIROSE   => 'Akira HIROSE',
     AINAME    => 'Satoshi Namai',
+    AKIHIRO   => 'Kodai Takahashi',
     AKIHITO   => 'Akihito Takeda',
     AKIRA     => 'Akira Hangai',
     AKITSUO   => 'Hiroaki Otsu',
@@ -25,6 +28,8 @@ use Acme::CPANAuthors::Register (
     AMARISAN  => 'Ryoji Tanida',
     AMIMOTO   => 'Aki Mimoto',
     ANAZAWA   => 'Ryo Anazawa',
+    ANNELI    => 'Yuki Izumi',
+    AONEKO    => 'Atsushi Watanabe',
     AQL       => 'Tetsuya Toyoda',
     ARGRATH   => 'SHIRAKATA Kentaro',
     ARISAWA   => 'Kosuke Arisawa',
@@ -55,10 +60,13 @@ use Acme::CPANAuthors::Register (
     DANKOGAI  => 'Dan Kogai',
     DAYFLOWER => 'ITO Nobuaki',
     DELPHINUS => 'JINNOUCHI Yasushi',
+    DENA      => 'DeNA  Co.,Ltd.',
     DGSCOPE   => 'Masayuki Komori',
     DMAKI     => 'Daisuke Maki',
+    DOKECHIN  => 'Tetsuya Tatsumi',
     DRAWNBOY  => 'Hideaki Tanaka',
     DSYRTM    => 'Mitsuru Yasuda',
+    EGAWATA   => 'Takashi Egawa',
     FNOBI     => 'Fujisawa Shin',
     FUJIMURA  => 'FUJIMURA Yuki',
     FUJISAWA  => 'Mizuki Fujisawa',
@@ -68,10 +76,12 @@ use Acme::CPANAuthors::Register (
     FUKUMURA  => 'Akinori Fukumura',
     FUTAYA    => 'Satoshi Futaya',
     GAOU      => 'Kazuharu Arakawa',
+    GENKIST   => 'Genki Sato',
     GFUJI     => 'Goro Fuji',
     GOCCY     => 'Masaaki Goshima',
     GOLOGO    => 'Yohei Yamaguchi',
     GUNYA     => 'GUNYARA-KUN',
+    GURISUGI  => 'Takuya Sugimoto',
     HAAZIME   => 'Hajime Sueyoshi',
     HAKOBE    => 'Yohei Fushii',
     HAMANO    => 'Tsukasa Hamano',
@@ -92,6 +102,7 @@ use Acme::CPANAuthors::Register (
     HIDEAKIO  => 'Hideaki Ohno',
     HIDEDEN   => 'Hideyuki Kakiuchi',
     HIDEHIGO  => 'Akihide Higo',
+    HIDEYUKI  => 'Hideyuki Ishiwata',
     HIGU      => 'Higuchi hiroyuki',
     HIKARINE  => 'Hajime Kurita',
     HIMACHOCO => 'Wataru Seto',
@@ -102,26 +113,34 @@ use Acme::CPANAuthors::Register (
     HIRATA    => 'HIRATA Yasuyuki',
     HIRATARA  => 'Masahiro Honma',
     HIRO      => 'hiroshi kitano',
+    HIROBANEX => 'HIROYUKI AKABANE',
+    HIROCUEKI => 'hiroshi ueki',
     HIROSE    => 'HIROSE Masaaki',
+    HIROTAKA  => 'Hirotaka Honda',
     HIROYUKI  => 'Hiroyuki Yamanaka',
     HIROYUKIM => 'Yamanaka Hiroyuki',
     HISAICHI  => 'HISADA KAZUKI',
     HISAJU    => 'Kikumoto HIsatoshi',
+    HITODE    => 'hitode 909',
     HIXI      => 'Hiroyoshi HOUCHI',
-    HRYK      => 'Hiroyuki Nakamura',
     HKOBA     => 'KOBAYASI, Hiroaki',
+    HMATSU    => 'Hajime Matsumoto',
     HOKKE     => 'Yoichi Hirota',
     HOLLY     => 'Akira Horimoto',
     HORIUCHI  => 'Yasuhiro Horiuchi',
+    HOTO      => 'Yuki Ishikawa',
     HOTSU     => 'Hiroaki Otsu',
     HRK       => 'Haruka Kataoka',
+    HRYK      => 'Hiroyuki Nakamura',
     HWAT      => 'WATANABE Hiroaki',
     ICHI      => 'Takuya Ichikawa',
+    ICHIGOTAK => 'ichigotake',
     IHARA     => 'Ikuhiro IHARA',
+    IIZUKA    => 'Nao Iizuka',
     IKEBE     => 'IKEBE Tomohiro',
     IKHRNET   => 'Tatsuya Ikehara',
     IKUTA     => 'Masahito Ikuta',
-    IIZUKA    => 'Nao Iizuka',
+    ILLO      => 'Ichito Nagata',
     INA       => 'INABA Hitoshi',
     INFINITH  => 'Hiroshi Tashiro',
     INGKTDS   => 'Inagaki Tadashi',
@@ -131,14 +150,17 @@ use Acme::CPANAuthors::Register (
     ISSM      => 'IWATA, Susumu',
     ITWARRIOR => 'Hitoshi Amano',
     IWAMATSU  => 'Nobuhiro Iwamatsu',
+    IWATA     => 'Motonori Iwata',
     JAMADAM   => 'Sugama Keita',
     JIRO      => 'Jiro Nishiguchi',
     JKONDO    => 'Junya Kondo',
     JUDIOO    => 'Udo Oji',
     JUNICHIRO => 'Junichiro Tobe',
+    JUNNAMA   => 'Junnama Noda',
     KAMIPO    => 'Ryuta Kamizono',
     KAMO      => 'Yoshikazu Kamoshida',
     KARUPA    => 'Kenta Sato',
+    KASHIWABA => 'Nobuyuki Kashiwabara',
     KAWABATA  => 'KAWABATA Kazumichi',
     KAWAMURAY => 'Yuto KAWAMURA',
     KAWASAKI  => 'Kawasaki Yusuke',
@@ -152,17 +174,21 @@ use Acme::CPANAuthors::Register (
     KENJIRO   => 'Kenjiro Hirakawa',
     KENSHIN   => 'Kenshin YAMADA',
     KENTARO   => 'Kentaro Kuribayashi',
+    KEYAMB    => 'YASUTAKE Kiyoshi',
     KIMATA    => 'Tetsuya KIMATA',
     KIMOTO    => 'Yuki Kimoto',
     KIMURA    => 'Takeshi Kimura',
     KINSAN    => 'Hitoshi Yokozawa',
     KIRIRIMOD => 'Yuichi Kiri',
     KISEKI    => 'keita iseki',
+    KITAK     => 'Keisuke Kita',
     KITAMAKI  => 'ryo kitamaki',
     KITANO    => 'dann',
     KIWANAMI  => 'Masashi Sakurai',
+    KIZASHI   => 'Kizashi Nagata',
     KMIYAZAKI => 'Keitaro Miyazaki',
     KNAGANO   => 'Keiichiro Nagano',
+    KNJSKYWKR => 'kenjiskywalker',
     KNOK      => 'NOKUBI Takatsugu',
     KOBAYASHI => 'Takeshi Kobayashi',
     KOBAYASI  => 'Hiroyuki Kobayasi',
@@ -173,9 +199,11 @@ use Acme::CPANAuthors::Register (
     KOMORIYA  => 'Kazunari Komoriya',
     KONDO     => 'Yoshiyuki KONDO',
     KOPUG     => 'Masahiro Funakoshi',
+    KOSHITA   => 'Kaoru Oshita',
     KOYACHI   => 'Tsutomu Koyachi',
     KPEE      => 'Kiyoaki KATAKURA',
     KSUZUKI   => 'Ken Suzuki',
+    KTAIGA    => 'Koji Taiga',
     KTAKATA   => 'Ken Takata',
     KTAT      => 'Kato Atsushi',
     KTMK      => 'ryo kita',
@@ -198,6 +226,8 @@ use Acme::CPANAuthors::Register (
     KZTOMITA  => 'Kazuyoshi Tomita',
     KZYS      => 'Kato Kazuyoshi',
     LAPIS     => 'Junichi Iwasaki',
+    LAYSAKURA => 'Sho Nakatani',
+    LIBITTE   => 'Nobuto Hachiya',
     LIMITUSUS => 'Tomoya KABE',
     LURKER    => 'Takumi KIMOTO',
     LUSHE     => 'Masatoshi Mizuno',
@@ -226,21 +256,25 @@ use Acme::CPANAuthors::Register (
     MASUTARO  => 'Kotaro MASUDA',
     MATSUMOTO => 'syushi matsumoto',
     MATTN     => 'Yasuhiro Matsumoto',
+    MERU      => 'meru_akimbo',
     MIKAGE    => 'SANO Taku',
     MIKI      => 'Takeshi Miki',
     MIKIHOSHI => 'KAN Fushihara',
     MIKIO     => 'Mikio Hirabayashi',
     MILANO    => 'Tsukui Akihiro',
     MINORU    => 'KAWAMOTO Minoru',
+    MIXI      => 'mixi, Inc.',
     MIYAGAWA  => 'Tatsuhiko Miyagawa',
     MIYAMUKO  => 'MIYAMUKO Katsuyuki',
     MIYAZAKI  => 'Ittetsu Miyazaki',
     MIZZY     => 'Gosuke Miyashita',
     MONMON    => 'Nobuo Kumagai',
     MORIYA    => 'Moriya Masaki',
+    MOSA      => 'Yusuke Enomoto',
     MOTEMEN   => 'motemen',
     MOZNION   => 'Taiki Kawakami',
     MRMT      => 'Jun Morimoto',
+    MSHIGE    => 'shigeharu matsumoto',
     MUGENKEN  => 'Mugen Kenichi',
     MUGIFLY   => 'Masanori Ohgita',
     MURATA    => 'Shingo Murata',
@@ -250,13 +284,17 @@ use Acme::CPANAuthors::Register (
     MYFINDER  => 'TatsuroHisamori',
     MYUJI     => 'Yuji Maeda',
     NABESHIMA => 'Masaaki NABESHIMA',
+    NAGAMI    => 'Shuhei Nagami',
     NAGATA    => 'Ichito Nagata',
     NAITO     => 'Naoyuki Ito',
+    NAKAYAMA  => 'Yasuhiro Nakayama',
+    NANTO     => 'nanto_vi (TOYAMA Nao)',
     NANZOU    => 'Takaaki Mizuno',
     NAOKIURAI => 'Naoki URAI',
     NAOY      => 'Naoyuki Ito',
     NAOYA     => 'Naoya Ito',
     NAOYAT    => 'Naoya "naochan" Tozuka',
+    NAOYU     => 'Naoyuki Ito',
     NAOYUKI   => 'Naoyuki Ito',
     NARAZAKA  => 'N Narazaka',
     NARIPON   => 'nari',
@@ -269,6 +307,7 @@ use Acme::CPANAuthors::Register (
     NGS       => 'Atsushi NAGASE',
     NISHIGAYA => 'NISHIGAYA, Yuki',
     NISHIKAWA => 'Kazuhiro Nishikawa',
+    NOBJAS    => 'noblejasper',
     NODAJUN   => 'JUNICHI NODA',
     NOGUCHI   => 'Tatsuya Noguchi',
     NORAYUNI  => 'Takahito Yamatoya',
@@ -281,10 +320,10 @@ use Acme::CPANAuthors::Register (
     OGASAWARA => 'leann ogasawara',
     OGATA     => 'OGATA Tetsuji',
     OGAWA     => 'Hirotaka Ogawa',
-    OKAMUUU   => 'Masao Okamura',
-    OKLAHOMER => 'Go Hagiwara',
     OINUME    => 'Kazuhiro Oinuma',
     OISHI     => 'Eisuke Oishi',
+    OKAMUUU   => 'Masao Okamura',
+    OKLAHOMER => 'Go Hagiwara',
     ONISHI    => 'Yasuhiro Onishi',
     OPPARA    => 'oppara',
     OUEST     => 'Daisuke NISHISAKA',
@@ -301,16 +340,22 @@ use Acme::CPANAuthors::Register (
     POCKET    => 'Masato Sogame',
     POPPEN    => 'Shinsuke Matsui',
     PUNYTAN   => 'punipuni',
+    QAZXSWEDC => 'hiroshi morimoto',
     QUEEN     => 'Yasuhiro Miyazaki',
     RIMFS     => 'Yuichiro Tanaka',
+    RINSATO   => 'takashi sato',
     RINTARO   => 'Rintaro Ishizaki',
     RITOU     => 'Ryo Ito',
     RIYWO     => 'Ryosuke IWANAGA',
     ROZARY    => 'Syunsuke Fujishiro',
     RYM       => 'Takayuki Murakami',
+    RYMIZUKI  => 'ryo iinuma',
+    RYO       => 'Ryo Utsunomiya',
     RYOCHIN   => 'Okamoto RYO',
     SADAHIRO  => 'SADAHIRO Tomoyuki',
+    SASAKURE  => 'Kei Shimada (sasakure_kei)',
     SASAO     => 'SASAO Takahiro',
+    SASATA    => 'Tatsuya "sasata299" Sasaki',
     SASAZUKA  => 'Seiji Sasazuka',
     SATOH     => 'cho45 (SATOH, Hiroh)',
     SATOSIN   => 'Shinichiro Sato',
@@ -324,6 +369,7 @@ use Acme::CPANAuthors::Register (
     SERA      => 'Kazuhiro Sera',
     SEYN      => 'Yasushi Nakajima',
     SHARADA   => 'Seiji Harada',
+    SHARP     => 'Motoki Kondo',
     SHIBAZAKI => 'Yuki Shibazaki',
     SHIBUYA   => 'Kazuhiro Shibuya',
     SHIGETA   => 'Takatsugu Shigeta',
@@ -331,11 +377,14 @@ use Acme::CPANAuthors::Register (
     SHIKONO   => 'Shinji KONO',
     SHIMAZU   => 'Yuki SHIMAZU',
     SHIMI     => 'Kazuhito Shimizu',
+    SHINGT    => 'Shinichi Goto',
     SHINPEI   => 'HAYASHI, Shinpei',
     SHIRAIWA  => 'Kazuma Shiraiwa',
     SHMORIMO  => 'Shigeki Morimoto',
+    SHOGO     => 'Shogo Ichinose',
     SHOHEIK   => 'Shohei Kameda',
     SHOT      => 'Shota Takayama',
+    SKAJI     => 'Shoichi Kaji',
     SKJM      => 'Shin Kojima',
     SKONNO    => 'Satoshi Konno',
     SKUBOTA   => 'Satoshi KUBOTA',
@@ -343,11 +392,13 @@ use Acme::CPANAuthors::Register (
     SNGJOKEN  => 'Shingo Kikugawa',
     SNUMANO   => 'Shugo Numano',
     SOH       => 'Soh Kitahara',
+    SOHASHI   => 'Sean Ohashi',
     SONGMU    => 'Masayuki Matsuki',
     SOTSA     => 'Shinichiro Sato',
     SPRINGMT  => 'Makoto Haruyama',
     SSEI      => 'Shinichiro Sei',
     STAKASHIO => 'Shin Takashio',
+    SUENAGA   => 'Hiroki Suenaga',
     SUGA      => 'suga masashi',
     SUGMAK    => 'Makoto Sugiyama',
     SUGYAN    => 'Yoshihiro Sugi',
@@ -365,6 +416,7 @@ use Acme::CPANAuthors::Register (
     TAILRIVER => 'Shinsuke Ogawa',
     TAIY      => 'Taisuke Yamada',
     TAIYOH    => 'Taiyoh Tanaka',
+    TAKANORI  => 'Takanori Uzuka',
     TAKASH    => 'shuhei takahashi',
     TAKASHI   => 'Takashi Saeki',
     TAKAYUKI  => 'Takayuki Ikeda',
@@ -375,14 +427,14 @@ use Acme::CPANAuthors::Register (
     TAKESHI   => 'tee wada',
     TAKESHIGE => 'Ken Takeshige',
     TAKESHUN  => 'Shun Takeyama',
-    TAKKYUN   => 'Takayuki Ikeda',
     TAKIMO    => 'Shinya Takimoto',
+    TAKKYUN   => 'Takayuki Ikeda',
     TAKUJI    => 'Nishibayashi Takuji',
     TAKUMI    => 'Takumi Hayashi',
     TAMAKOTO  => 'Tanaka Makoto',
     TAMASHIRO => 'Yuji Tamashiro',
     TANABE    => 'Hisao Tanabe',
-    TNAGA     => 'Tomohide Nagasima',
+    TANAKA    => 'Tanaka Tatsuya',
     TANIGUCHI => 'Koichi Taniguchi',
     TANIMOTO  => 'Satoshi Tanimoto',
     TARAO     => 'INA Lintaro',
@@ -390,10 +442,15 @@ use Acme::CPANAuthors::Register (
     TAROK     => 'Taro Kawagishi',
     TATE      => 'tateisu',
     TATENO    => 'Yuichi Tateno',
+    TATSUYAGI => 'Tatsuya Yagi',
     TAWAN     => 'Taro Funaki',
     THORIKAWA => 'Takahiro Horikawa',
+    TISHIDUKA => 'Takeshi ISHIDUKA',
     TKURITA   => 'Tetsuro KURITA',
     TMAESAKA  => 'Toru Maesaka',
+    TMITOH    => 'Tomoaki Itoh',
+    TMITZ     => 'Tomohiro Mitsumune',
+    TNAGA     => 'Tomohide Nagasima',
     TNISHINO  => 'Taro Nishino',
     TOAMANO   => 'Tomoo Amano',
     TOCIYUKI  => 'MIZUTANI, Tociyuki',
@@ -430,13 +487,14 @@ use Acme::CPANAuthors::Register (
     UNLEARNED => 'Takashi Uesugi',
     USUALOMA  => 'Taku Amano',
     UTAANI    => 'Takeshi Ueno',
+    VPAM      => 'singo suda',
     WAKAPON   => 'ASANO Kazunari',
     WATA      => 'Kouji Watanabe',
     WATANABE  => 'WATANABE Hirofumi',
     WOREMACX  => 'Wore Macx',
     XAICRON   => 'Yuji Shimada',
-    XOR       => 'Izumi Kawashima',
     XCEZX     => 'Tsuyoshi Maekawa',
+    XOR       => 'Izumi Kawashima',
     YAKEX     => 'Yasutaka ATARASHI',
     YAMAKURA  => 'Kazuhiko Yamakura',
     YAMAMOTO  => 'Ryuzo Yamamoto',
@@ -444,17 +502,22 @@ use Acme::CPANAuthors::Register (
     YANA      => 'Toshimitu Yanagisawa',
     YANBE     => 'Yusuke Yanbe',
     YANMAR    => 'Yamamoto Keiichiro',
+    YANOTHER  => 'Daisuke (yet another) Maki',
     YAPPO     => 'Kazuhiro Osawa',
     YASU      => 'Yasushi Saito',
     YASUHIRO  => 'Yasuhiro Onishi',
+    YAUC      => 'Inoshika cho',
     YAYOHEI   => 'Yohei Yamamoto',
     YIBE      => 'Yuki Ibe',
     YISHINO   => 'Yukio Ishino',
+    YOKKUNS   => 'Yohei Sato',
     YOSHIAKI  => 'Yoshiaki Shiokawa',
     YOSHIDA   => 'Hironori Yoshida',
     YOSHIMI   => 'Keiji Yoshimi',
     YOSHIOKA  => 'Yuki Yoshioka',
+    YOSIZUKA  => 'yukio kusakabe',
     YOSTY     => 'Koji Komatsu',
+    YOSUKEF   => 'Yosuke Furukawa',
     YSAS      => 'Yasuhiro Sasama',
     YSASAKI   => 'Yoshihiro Sasaki',
     YSHIBATA  => 'Yusuke Shibata',
@@ -465,18 +528,20 @@ use Acme::CPANAuthors::Register (
     YUKINOBU  => 'NAGAYASU Yukinobu',
     YUKIO     => 'Yukio Suzuki',
     YUMATSUMO => 'yuya matsumoto',
-    YURYU     => 'Haruka Iwao',
-    YOKKUNS   => 'Yohei Sato',
     YUPUG     => 'Yu Isobe',
+    YURYU     => 'Haruka Iwao',
     YUSUKE    => 'Yusuke Shibata',
     YUSUKEBE  => 'Yusuke Wada',
     YUTA      => 'MASUDA Yuta',
+    YUTACHI   => 'Yutaka Kuno',
     YUUKI     => 'Yuuki Tsubouchi',
     YUYAW     => 'Yuya Watanabe',
     YWATASE   => 'Yusuke Watase',
     ZENTOOO   => 'Naosuke Yokoe',
     ZIGOROU   => 'Toru Yamaguchi',
     ZIGUZAGU  => 'Hiroshi Sakai',
+    ZOETIN    => 'Yusuke Nozoe',
+    ZONCOEN   => 'Kenta Mori',
 );
 
 1;
